Documentation
¶
Overview ¶
SPDX-License-Identifier: Apache-2.0 Package v1alpha1 defines front.in-cloud.io API types.
Group: dashboard.cozystack.io Version: v1alpha1
Package v1alpha1 contains API Schema definitions for the v1alpha1 API group. +kubebuilder:object:generate=true +groupName=dashboard.cozystack.io
Index ¶
- Variables
- type ArbitrarySpec
- type Breadcrumb
- type BreadcrumbInside
- type BreadcrumbInsideList
- type BreadcrumbList
- type CFOMapping
- type CFOMappingList
- type CommonStatus
- type CustomColumnsOverride
- type CustomColumnsOverrideList
- type CustomFormsOverride
- type CustomFormsOverrideList
- type CustomFormsPrefill
- type CustomFormsPrefillList
- type Factory
- type FactoryList
- type MarketplacePanel
- type MarketplacePanelList
- type Navigation
- type NavigationList
- type Sidebar
- type SidebarList
- type TableUriMapping
- type TableUriMappingList
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects. GroupVersion = schema.GroupVersion{Group: "dashboard.cozystack.io", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme. SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type ArbitrarySpec ¶
type ArbitrarySpec struct {
// +kubebuilder:validation:XPreserveUnknownFields
// +kubebuilder:pruning:PreserveUnknownFields
v1.JSON `json:",inline"`
}
ArbitrarySpec holds schemaless user data and preserves unknown fields. We map the entire .spec to a single JSON payload to mirror the CRDs you provided. NOTE: Using apiextensionsv1.JSON avoids losing arbitrary structure during round-trips.
func (*ArbitrarySpec) DeepCopy ¶
func (in *ArbitrarySpec) DeepCopy() *ArbitrarySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ArbitrarySpec.
func (*ArbitrarySpec) DeepCopyInto ¶
func (in *ArbitrarySpec) DeepCopyInto(out *ArbitrarySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Breadcrumb ¶
type Breadcrumb struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ArbitrarySpec `json:"spec"`
Status CommonStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:resource:path=breadcrumbs,scope=Cluster +kubebuilder:subresource:status
func (*Breadcrumb) DeepCopy ¶
func (in *Breadcrumb) DeepCopy() *Breadcrumb
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Breadcrumb.
func (*Breadcrumb) DeepCopyInto ¶
func (in *Breadcrumb) DeepCopyInto(out *Breadcrumb)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Breadcrumb) DeepCopyObject ¶
func (in *Breadcrumb) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BreadcrumbInside ¶
type BreadcrumbInside struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ArbitrarySpec `json:"spec"`
Status CommonStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:resource:path=breadcrumbsinside,scope=Cluster +kubebuilder:subresource:status
func (*BreadcrumbInside) DeepCopy ¶
func (in *BreadcrumbInside) DeepCopy() *BreadcrumbInside
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BreadcrumbInside.
func (*BreadcrumbInside) DeepCopyInto ¶
func (in *BreadcrumbInside) DeepCopyInto(out *BreadcrumbInside)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BreadcrumbInside) DeepCopyObject ¶
func (in *BreadcrumbInside) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BreadcrumbInsideList ¶
type BreadcrumbInsideList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []BreadcrumbInside `json:"items"`
}
+kubebuilder:object:root=true
func (*BreadcrumbInsideList) DeepCopy ¶
func (in *BreadcrumbInsideList) DeepCopy() *BreadcrumbInsideList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BreadcrumbInsideList.
func (*BreadcrumbInsideList) DeepCopyInto ¶
func (in *BreadcrumbInsideList) DeepCopyInto(out *BreadcrumbInsideList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BreadcrumbInsideList) DeepCopyObject ¶
func (in *BreadcrumbInsideList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BreadcrumbList ¶
type BreadcrumbList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Breadcrumb `json:"items"`
}
+kubebuilder:object:root=true
func (*BreadcrumbList) DeepCopy ¶
func (in *BreadcrumbList) DeepCopy() *BreadcrumbList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BreadcrumbList.
func (*BreadcrumbList) DeepCopyInto ¶
func (in *BreadcrumbList) DeepCopyInto(out *BreadcrumbList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BreadcrumbList) DeepCopyObject ¶
func (in *BreadcrumbList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CFOMapping ¶ added in v1.0.0
type CFOMapping struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ArbitrarySpec `json:"spec"`
Status CommonStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:resource:path=cfomappings,scope=Cluster +kubebuilder:subresource:status
func (*CFOMapping) DeepCopy ¶ added in v1.0.0
func (in *CFOMapping) DeepCopy() *CFOMapping
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CFOMapping.
func (*CFOMapping) DeepCopyInto ¶ added in v1.0.0
func (in *CFOMapping) DeepCopyInto(out *CFOMapping)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CFOMapping) DeepCopyObject ¶ added in v1.0.0
func (in *CFOMapping) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CFOMappingList ¶ added in v1.0.0
type CFOMappingList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CFOMapping `json:"items"`
}
+kubebuilder:object:root=true
func (*CFOMappingList) DeepCopy ¶ added in v1.0.0
func (in *CFOMappingList) DeepCopy() *CFOMappingList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CFOMappingList.
func (*CFOMappingList) DeepCopyInto ¶ added in v1.0.0
func (in *CFOMappingList) DeepCopyInto(out *CFOMappingList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CFOMappingList) DeepCopyObject ¶ added in v1.0.0
func (in *CFOMappingList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CommonStatus ¶
type CommonStatus struct {
// ObservedGeneration reflects the most recent generation observed by the controller.
// +optional
ObservedGeneration int64 `json:"observedGeneration,omitempty"`
// Conditions represent the latest available observations of an object's state.
// +optional
Conditions []metav1.Condition `json:"conditions,omitempty"`
}
CommonStatus is a generic Status block with Kubernetes conditions.
func (*CommonStatus) DeepCopy ¶
func (in *CommonStatus) DeepCopy() *CommonStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CommonStatus.
func (*CommonStatus) DeepCopyInto ¶
func (in *CommonStatus) DeepCopyInto(out *CommonStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CustomColumnsOverride ¶
type CustomColumnsOverride struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ArbitrarySpec `json:"spec"`
Status CommonStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:resource:path=customcolumnsoverrides,scope=Cluster +kubebuilder:subresource:status
func (*CustomColumnsOverride) DeepCopy ¶
func (in *CustomColumnsOverride) DeepCopy() *CustomColumnsOverride
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomColumnsOverride.
func (*CustomColumnsOverride) DeepCopyInto ¶
func (in *CustomColumnsOverride) DeepCopyInto(out *CustomColumnsOverride)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CustomColumnsOverride) DeepCopyObject ¶
func (in *CustomColumnsOverride) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CustomColumnsOverrideList ¶
type CustomColumnsOverrideList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CustomColumnsOverride `json:"items"`
}
+kubebuilder:object:root=true
func (*CustomColumnsOverrideList) DeepCopy ¶
func (in *CustomColumnsOverrideList) DeepCopy() *CustomColumnsOverrideList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomColumnsOverrideList.
func (*CustomColumnsOverrideList) DeepCopyInto ¶
func (in *CustomColumnsOverrideList) DeepCopyInto(out *CustomColumnsOverrideList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CustomColumnsOverrideList) DeepCopyObject ¶
func (in *CustomColumnsOverrideList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CustomFormsOverride ¶
type CustomFormsOverride struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ArbitrarySpec `json:"spec"`
Status CommonStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:resource:path=customformsoverrides,scope=Cluster,shortName=cfo +kubebuilder:subresource:status
func (*CustomFormsOverride) DeepCopy ¶
func (in *CustomFormsOverride) DeepCopy() *CustomFormsOverride
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomFormsOverride.
func (*CustomFormsOverride) DeepCopyInto ¶
func (in *CustomFormsOverride) DeepCopyInto(out *CustomFormsOverride)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CustomFormsOverride) DeepCopyObject ¶
func (in *CustomFormsOverride) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CustomFormsOverrideList ¶
type CustomFormsOverrideList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CustomFormsOverride `json:"items"`
}
+kubebuilder:object:root=true
func (*CustomFormsOverrideList) DeepCopy ¶
func (in *CustomFormsOverrideList) DeepCopy() *CustomFormsOverrideList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomFormsOverrideList.
func (*CustomFormsOverrideList) DeepCopyInto ¶
func (in *CustomFormsOverrideList) DeepCopyInto(out *CustomFormsOverrideList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CustomFormsOverrideList) DeepCopyObject ¶
func (in *CustomFormsOverrideList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CustomFormsPrefill ¶
type CustomFormsPrefill struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ArbitrarySpec `json:"spec"`
Status CommonStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:resource:path=customformsprefills,scope=Cluster,shortName=cfp +kubebuilder:subresource:status
func (*CustomFormsPrefill) DeepCopy ¶
func (in *CustomFormsPrefill) DeepCopy() *CustomFormsPrefill
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomFormsPrefill.
func (*CustomFormsPrefill) DeepCopyInto ¶
func (in *CustomFormsPrefill) DeepCopyInto(out *CustomFormsPrefill)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CustomFormsPrefill) DeepCopyObject ¶
func (in *CustomFormsPrefill) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CustomFormsPrefillList ¶
type CustomFormsPrefillList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CustomFormsPrefill `json:"items"`
}
+kubebuilder:object:root=true
func (*CustomFormsPrefillList) DeepCopy ¶
func (in *CustomFormsPrefillList) DeepCopy() *CustomFormsPrefillList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomFormsPrefillList.
func (*CustomFormsPrefillList) DeepCopyInto ¶
func (in *CustomFormsPrefillList) DeepCopyInto(out *CustomFormsPrefillList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CustomFormsPrefillList) DeepCopyObject ¶
func (in *CustomFormsPrefillList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type Factory ¶
type Factory struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ArbitrarySpec `json:"spec"`
Status CommonStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:resource:path=factories,scope=Cluster +kubebuilder:subresource:status
func (*Factory) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Factory.
func (*Factory) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Factory) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type FactoryList ¶
type FactoryList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Factory `json:"items"`
}
+kubebuilder:object:root=true
func (*FactoryList) DeepCopy ¶
func (in *FactoryList) DeepCopy() *FactoryList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FactoryList.
func (*FactoryList) DeepCopyInto ¶
func (in *FactoryList) DeepCopyInto(out *FactoryList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*FactoryList) DeepCopyObject ¶
func (in *FactoryList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MarketplacePanel ¶
type MarketplacePanel struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ArbitrarySpec `json:"spec"`
Status CommonStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:resource:path=marketplacepanels,scope=Cluster +kubebuilder:subresource:status
func (*MarketplacePanel) DeepCopy ¶
func (in *MarketplacePanel) DeepCopy() *MarketplacePanel
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MarketplacePanel.
func (*MarketplacePanel) DeepCopyInto ¶
func (in *MarketplacePanel) DeepCopyInto(out *MarketplacePanel)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MarketplacePanel) DeepCopyObject ¶
func (in *MarketplacePanel) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MarketplacePanelList ¶
type MarketplacePanelList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []MarketplacePanel `json:"items"`
}
+kubebuilder:object:root=true
func (*MarketplacePanelList) DeepCopy ¶
func (in *MarketplacePanelList) DeepCopy() *MarketplacePanelList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MarketplacePanelList.
func (*MarketplacePanelList) DeepCopyInto ¶
func (in *MarketplacePanelList) DeepCopyInto(out *MarketplacePanelList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MarketplacePanelList) DeepCopyObject ¶
func (in *MarketplacePanelList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type Navigation ¶
type Navigation struct {
}
+kubebuilder:object:root=true +kubebuilder:resource:path=navigations,scope=Cluster +kubebuilder:subresource:status
func (*Navigation) DeepCopy ¶
func (in *Navigation) DeepCopy() *Navigation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Navigation.
func (*Navigation) DeepCopyInto ¶
func (in *Navigation) DeepCopyInto(out *Navigation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Navigation) DeepCopyObject ¶
func (in *Navigation) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type NavigationList ¶
type NavigationList struct {
}
+kubebuilder:object:root=true
func (*NavigationList) DeepCopy ¶
func (in *NavigationList) DeepCopy() *NavigationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NavigationList.
func (*NavigationList) DeepCopyInto ¶
func (in *NavigationList) DeepCopyInto(out *NavigationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NavigationList) DeepCopyObject ¶
func (in *NavigationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type Sidebar ¶
type Sidebar struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ArbitrarySpec `json:"spec"`
Status CommonStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:resource:path=sidebars,scope=Cluster +kubebuilder:subresource:status
func (*Sidebar) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Sidebar.
func (*Sidebar) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Sidebar) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type SidebarList ¶
type SidebarList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Sidebar `json:"items"`
}
+kubebuilder:object:root=true
func (*SidebarList) DeepCopy ¶
func (in *SidebarList) DeepCopy() *SidebarList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SidebarList.
func (*SidebarList) DeepCopyInto ¶
func (in *SidebarList) DeepCopyInto(out *SidebarList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*SidebarList) DeepCopyObject ¶
func (in *SidebarList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TableUriMapping ¶
type TableUriMapping struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ArbitrarySpec `json:"spec"`
Status CommonStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:resource:path=tableurimappings,scope=Cluster +kubebuilder:subresource:status
func (*TableUriMapping) DeepCopy ¶
func (in *TableUriMapping) DeepCopy() *TableUriMapping
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TableUriMapping.
func (*TableUriMapping) DeepCopyInto ¶
func (in *TableUriMapping) DeepCopyInto(out *TableUriMapping)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TableUriMapping) DeepCopyObject ¶
func (in *TableUriMapping) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TableUriMappingList ¶
type TableUriMappingList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []TableUriMapping `json:"items"`
}
+kubebuilder:object:root=true
func (*TableUriMappingList) DeepCopy ¶
func (in *TableUriMappingList) DeepCopy() *TableUriMappingList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TableUriMappingList.
func (*TableUriMappingList) DeepCopyInto ¶
func (in *TableUriMappingList) DeepCopyInto(out *TableUriMappingList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TableUriMappingList) DeepCopyObject ¶
func (in *TableUriMappingList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.