controller

package
v0.41.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2026 License: Apache-2.0 Imports: 26 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CozystackResourceDefinitionHelmReconciler added in v0.40.0

type CozystackResourceDefinitionHelmReconciler struct {
	client.Client
	Scheme *runtime.Scheme
}

CozystackResourceDefinitionHelmReconciler reconciles CozystackResourceDefinitions and updates related HelmReleases when a CozyRD changes. This controller does NOT watch HelmReleases to avoid mutual reconciliation storms with Flux's helm-controller.

func (*CozystackResourceDefinitionHelmReconciler) Reconcile added in v0.40.0

func (*CozystackResourceDefinitionHelmReconciler) SetupWithManager added in v0.40.0

type CozystackResourceDefinitionReconciler added in v0.35.0

type CozystackResourceDefinitionReconciler struct {
	client.Client
	Scheme *runtime.Scheme

	Debounce time.Duration

	CozystackAPIKind string
	// contains filtered or unexported fields
}

func (*CozystackResourceDefinitionReconciler) Reconcile added in v0.35.0

func (*CozystackResourceDefinitionReconciler) SetupWithManager added in v0.35.0

func (r *CozystackResourceDefinitionReconciler) SetupWithManager(mgr ctrl.Manager) error

type WorkloadMonitorReconciler

type WorkloadMonitorReconciler struct {
	client.Client
	Scheme *runtime.Scheme
}

WorkloadMonitorReconciler reconciles a WorkloadMonitor object

func (*WorkloadMonitorReconciler) Reconcile

Reconcile is the main reconcile loop. 1. It reconciles WorkloadMonitor objects themselves (create/update/delete). 2. It also reconciles Pod events mapped to WorkloadMonitor via label selector.

func (*WorkloadMonitorReconciler) SetupWithManager

func (r *WorkloadMonitorReconciler) SetupWithManager(mgr ctrl.Manager) error

SetupWithManager registers our controller with the Manager and sets up watches.

type WorkloadReconciler added in v0.30.0

type WorkloadReconciler struct {
	client.Client
	Scheme *runtime.Scheme
}

WorkloadMonitorReconciler reconciles a WorkloadMonitor object

func (*WorkloadReconciler) Reconcile added in v0.30.0

func (r *WorkloadReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)

workload_controller.go

func (*WorkloadReconciler) SetupWithManager added in v0.30.0

func (r *WorkloadReconciler) SetupWithManager(mgr ctrl.Manager) error

SetupWithManager registers our controller with the Manager and sets up watches.

Directories

Path Synopsis

Jump to