fluxinstall

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Install

func Install(ctx context.Context, k8sClient client.Client, writeEmbeddedManifests func(string) error) error

Install installs Flux components using embedded manifests. It extracts the manifests and applies them to the cluster. The namespace is automatically determined from the Namespace object in the manifests.

func WriteEmbeddedManifests

func WriteEmbeddedManifests(dir string) error

WriteEmbeddedManifests extracts embedded Flux manifests to a temporary directory.

Types

This section is empty.

Jump to