v1alpha1

package
v0.40.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 2, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package v1alpha1 is the v1alpha1 version of the API.

Index

Constants

const (
	ApplicationKindLabel  = "apps.cozystack.io/application.kind"
	ApplicationGroupLabel = "apps.cozystack.io/application.group"
	ApplicationNameLabel  = "apps.cozystack.io/application.name"
)

Application label keys used to identify and filter HelmReleases

const GroupName = "apps.cozystack.io"

GroupName is the API group for every resource in this package.

Variables

var (
	// SchemeBuilder is used by generated deepcopy code.
	SchemeBuilder runtime.SchemeBuilder

	AddToScheme = localSchemeBuilder.AddToScheme
)
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: "v1alpha1"}

SchemeGroupVersion is the canonical {group,version} for v1alpha1.

Functions

func RegisterConversions

func RegisterConversions(s *runtime.Scheme) error

RegisterConversions adds conversion functions to the given scheme. Public to allow building arbitrary schemes.

func RegisterDefaults

func RegisterDefaults(scheme *runtime.Scheme) error

RegisterDefaults adds defaulters functions to the given scheme. Public to allow building arbitrary schemes. All generated defaulters are covering - they call all nested defaulters.

func RegisterDynamicTypes

func RegisterDynamicTypes(scheme *runtime.Scheme, cfg *config.ResourceConfig) error

RegisterDynamicTypes adds per-tenant “Application” kinds that are only known at runtime from a config file.

func Resource

func Resource(resource string) schema.GroupResource

Resource turns an unqualified resource name into a fully-qualified one.

Types

type Application

type Application struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`

	AppVersion string `json:"appVersion,omitempty" protobuf:"bytes,1,opt,name=version"`
	// +optional
	Spec   *apiextensionsv1.JSON `json:"spec,omitempty" protobuf:"bytes,2,opt,name=spec"`
	Status ApplicationStatus     `json:"status,omitempty" protobuf:"bytes,3,opt,name=status"`
}

Application is an example type with a spec and a status.

func (*Application) DeepCopy

func (in *Application) DeepCopy() *Application

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Application.

func (*Application) DeepCopyInto

func (in *Application) DeepCopyInto(out *Application)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*Application) DeepCopyObject

func (in *Application) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (Application) GetConditions

func (in Application) GetConditions() []metav1.Condition

GetConditions returns the status conditions of the object.

func (*Application) SetConditions

func (in *Application) SetConditions(conditions []metav1.Condition)

SetConditions sets the status conditions on the object.

type ApplicationList

type ApplicationList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`

	Items []Application `json:"items" protobuf:"bytes,2,rep,name=items"`
}

ApplicationList is a list of Application objects.

func (*ApplicationList) DeepCopy

func (in *ApplicationList) DeepCopy() *ApplicationList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApplicationList.

func (*ApplicationList) DeepCopyInto

func (in *ApplicationList) DeepCopyInto(out *ApplicationList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ApplicationList) DeepCopyObject

func (in *ApplicationList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type ApplicationStatus

type ApplicationStatus struct {
	// Conditions holds the conditions for the Application.
	// +optional
	Version    string             `json:"version,omitempty"`
	Conditions []metav1.Condition `json:"conditions,omitempty"`
	// Namespace holds the computed namespace for Tenant applications.
	// +optional
	Namespace string `json:"namespace,omitempty"`
}

ApplicationStatus is the status of a Application.

func (*ApplicationStatus) DeepCopy

func (in *ApplicationStatus) DeepCopy() *ApplicationStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApplicationStatus.

func (*ApplicationStatus) DeepCopyInto

func (in *ApplicationStatus) DeepCopyInto(out *ApplicationStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to