v1alpha1

package
v0.37.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 4, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package v1alpha1 is the v1alpha1 version of the API.

SPDX-License-Identifier: Apache-2.0

SPDX-License-Identifier: Apache-2.0

SPDX-License-Identifier: Apache-2.0

Index

Constants

const GroupName = "core.cozystack.io"

GroupName is the API group for every resource in this package.

const TenantResourceLabelKey = "internal.cozystack.io/tenantresource"
const TenantResourceLabelValue = "true"

Variables

var (
	// SchemeBuilder is used by generated deepcopy code.
	SchemeBuilder runtime.SchemeBuilder

	AddToScheme = localSchemeBuilder.AddToScheme
)
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: "v1alpha1"}

SchemeGroupVersion is the canonical {group,version} for v1alpha1.

Functions

func RegisterConversions

func RegisterConversions(s *runtime.Scheme) error

RegisterConversions adds conversion functions to the given scheme. Public to allow building arbitrary schemes.

func RegisterDefaults

func RegisterDefaults(scheme *runtime.Scheme) error

RegisterDefaults adds defaulters functions to the given scheme. Public to allow building arbitrary schemes. All generated defaulters are covering - they call all nested defaulters.

func RegisterStaticTypes

func RegisterStaticTypes(scheme *runtime.Scheme)

RegisterStaticTypes adds *compile-time* resources such as TenantNamespace.

func Resource

func Resource(resource string) schema.GroupResource

Resource turns an unqualified resource name into a fully-qualified one.

Types

type TenantModule

type TenantModule struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	// AppVersion represents the version of the Helm chart
	AppVersion string `json:"appVersion,omitempty"`

	// Status contains the module status
	Status TenantModuleStatus `json:"status,omitempty"`
}

TenantModule represents a HelmRelease with the label internal.cozystack.io/tenantmodule=true

func (*TenantModule) DeepCopy

func (in *TenantModule) DeepCopy() *TenantModule

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TenantModule.

func (*TenantModule) DeepCopyInto

func (in *TenantModule) DeepCopyInto(out *TenantModule)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*TenantModule) DeepCopyObject

func (in *TenantModule) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type TenantModuleList

type TenantModuleList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []TenantModule `json:"items"`
}

TenantModuleList contains a list of TenantModule

func (*TenantModuleList) DeepCopy

func (in *TenantModuleList) DeepCopy() *TenantModuleList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TenantModuleList.

func (*TenantModuleList) DeepCopyInto

func (in *TenantModuleList) DeepCopyInto(out *TenantModuleList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*TenantModuleList) DeepCopyObject

func (in *TenantModuleList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type TenantModuleStatus

type TenantModuleStatus struct {
	// Version represents the last attempted revision
	Version string `json:"version,omitempty"`

	// Conditions represent the latest available observations of the module's state
	Conditions []metav1.Condition `json:"conditions,omitempty"`
}

TenantModuleStatus represents the status of a TenantModule

func (*TenantModuleStatus) DeepCopy

func (in *TenantModuleStatus) DeepCopy() *TenantModuleStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TenantModuleStatus.

func (*TenantModuleStatus) DeepCopyInto

func (in *TenantModuleStatus) DeepCopyInto(out *TenantModuleStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TenantNamespace

type TenantNamespace struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`
}

TenantNamespace is a thin wrapper around ObjectMeta. It has no spec/status because it merely reflects an existing Namespace object.

func (*TenantNamespace) DeepCopy

func (in *TenantNamespace) DeepCopy() *TenantNamespace

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TenantNamespace.

func (*TenantNamespace) DeepCopyInto

func (in *TenantNamespace) DeepCopyInto(out *TenantNamespace)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*TenantNamespace) DeepCopyObject

func (in *TenantNamespace) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type TenantNamespaceList

type TenantNamespaceList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []TenantNamespace `json:"items"`
}

TenantNamespaceList is the list variant for TenantNamespace.

func (*TenantNamespaceList) DeepCopy

func (in *TenantNamespaceList) DeepCopy() *TenantNamespaceList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TenantNamespaceList.

func (*TenantNamespaceList) DeepCopyInto

func (in *TenantNamespaceList) DeepCopyInto(out *TenantNamespaceList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*TenantNamespaceList) DeepCopyObject

func (in *TenantNamespaceList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type TenantSecret

type TenantSecret struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	// Same semantics as core/v1 Secret.
	Type       string            `json:"type,omitempty"`
	Data       map[string][]byte `json:"data,omitempty"`
	StringData map[string]string `json:"stringData,omitempty"` // write-only hint
}

func (*TenantSecret) DeepCopy

func (in *TenantSecret) DeepCopy() *TenantSecret

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TenantSecret.

func (*TenantSecret) DeepCopyInto

func (in *TenantSecret) DeepCopyInto(out *TenantSecret)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*TenantSecret) DeepCopyObject

func (in *TenantSecret) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type TenantSecretEntry

type TenantSecretEntry struct {
	Name  string `json:"name,omitempty"`
	Key   string `json:"key,omitempty"`
	Value string `json:"value,omitempty"`
}

TenantSecretEntry represents a single key from a Secret's data.

func (*TenantSecretEntry) DeepCopy

func (in *TenantSecretEntry) DeepCopy() *TenantSecretEntry

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TenantSecretEntry.

func (*TenantSecretEntry) DeepCopyInto

func (in *TenantSecretEntry) DeepCopyInto(out *TenantSecretEntry)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TenantSecretList

type TenantSecretList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []TenantSecret `json:"items"`
}

func (*TenantSecretList) DeepCopy

func (in *TenantSecretList) DeepCopy() *TenantSecretList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TenantSecretList.

func (*TenantSecretList) DeepCopyInto

func (in *TenantSecretList) DeepCopyInto(out *TenantSecretList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*TenantSecretList) DeepCopyObject

func (in *TenantSecretList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type TenantSecretsTable

type TenantSecretsTable struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Data TenantSecretEntry `json:"data,omitempty"`
}

TenantSecretsTable is a virtual, namespaced resource that exposes every key of Secrets labelled cozystack.io/ui=true as a separate object.

func (*TenantSecretsTable) DeepCopy

func (in *TenantSecretsTable) DeepCopy() *TenantSecretsTable

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TenantSecretsTable.

func (*TenantSecretsTable) DeepCopyInto

func (in *TenantSecretsTable) DeepCopyInto(out *TenantSecretsTable)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*TenantSecretsTable) DeepCopyObject

func (in *TenantSecretsTable) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type TenantSecretsTableList

type TenantSecretsTableList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []TenantSecretsTable `json:"items"`
}

func (*TenantSecretsTableList) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TenantSecretsTableList.

func (*TenantSecretsTableList) DeepCopyInto

func (in *TenantSecretsTableList) DeepCopyInto(out *TenantSecretsTableList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*TenantSecretsTableList) DeepCopyObject

func (in *TenantSecretsTableList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

Jump to