apiserver

package
v0.36.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 18, 2025 License: Apache-2.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// Scheme defines methods for serializing and deserializing API objects.
	Scheme = runtime.NewScheme()
	// Codecs provides methods for retrieving codecs and serializers for specific
	// versions and content types.
	Codecs            = serializer.NewCodecFactory(Scheme)
	AppsComponentName = "apps"
)

Functions

This section is empty.

Types

type AppsServer

type AppsServer struct {
	GenericAPIServer *genericapiserver.GenericAPIServer
}

AppsServer holds the state for the Kubernetes master/api server.

type CompletedConfig

type CompletedConfig struct {
	// contains filtered or unexported fields
}

CompletedConfig embeds a private pointer that cannot be created outside of this package.

func (CompletedConfig) New

func (c CompletedConfig) New() (*AppsServer, error)

New returns a new instance of AppsServer from the given configuration.

type Config

type Config struct {
	GenericConfig  *genericapiserver.RecommendedConfig
	ResourceConfig *config.ResourceConfig
}

Config defines the configuration for the apiserver.

func (*Config) Complete

func (cfg *Config) Complete() CompletedConfig

Complete fills in any fields that are not set but are required for valid operation.

Jump to