Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CozyVersionToKubeVersion ¶ added in v0.37.0
CozyVersionToKubeVersion defines the version mapping between the Cozy component and kube
func NewCommandStartCozyServer ¶ added in v0.37.0
func NewCommandStartCozyServer(ctx context.Context, defaults *CozyServerOptions) *cobra.Command
NewCommandStartCozyServer provides a CLI handler for the 'start apps-server' command
Types ¶
type CozyServerOptions ¶ added in v0.37.0
type CozyServerOptions struct {
RecommendedOptions *genericoptions.RecommendedOptions
StdOut io.Writer
StdErr io.Writer
AlternateDNS []string
Client client.Client
// Add a field to store the configuration
ResourceConfig *config.ResourceConfig
}
CozyServerOptions holds the state for the Cozy API server
func NewCozyServerOptions ¶ added in v0.37.0
func NewCozyServerOptions(out, errOut io.Writer) *CozyServerOptions
NewCozyServerOptions returns a new instance of CozyServerOptions
func (*CozyServerOptions) Complete ¶ added in v0.37.0
func (o *CozyServerOptions) Complete() error
Complete fills in the fields that are not set
func (*CozyServerOptions) Config ¶ added in v0.37.0
func (o *CozyServerOptions) Config() (*apiserver.Config, error)
Config returns the configuration for the API server based on CozyServerOptions
func (CozyServerOptions) RunCozyServer ¶ added in v0.37.0
func (o CozyServerOptions) RunCozyServer(ctx context.Context) error
RunCozyServer launches a new CozyServer based on CozyServerOptions
func (CozyServerOptions) Validate ¶ added in v0.37.0
func (o CozyServerOptions) Validate(args []string) error
Validate checks the correctness of the options
Click to show internal directories.
Click to hide internal directories.