v1alpha1

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ApplicationApplyConfiguration

type ApplicationApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration    `json:",inline"`
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	AppVersion                       *string                              `json:"appVersion,omitempty"`
	Spec                             *apiextensionsv1.JSON                `json:"spec,omitempty"`
	Status                           *ApplicationStatusApplyConfiguration `json:"status,omitempty"`
}

ApplicationApplyConfiguration represents a declarative configuration of the Application type for use with apply.

func Application

func Application(name, namespace string) *ApplicationApplyConfiguration

Application constructs a declarative configuration of the Application type for use with apply.

func (*ApplicationApplyConfiguration) GetAPIVersion added in v1.0.0

func (b *ApplicationApplyConfiguration) GetAPIVersion() *string

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*ApplicationApplyConfiguration) GetKind added in v1.0.0

func (b *ApplicationApplyConfiguration) GetKind() *string

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*ApplicationApplyConfiguration) GetName

func (b *ApplicationApplyConfiguration) GetName() *string

GetName retrieves the value of the Name field in the declarative configuration.

func (*ApplicationApplyConfiguration) GetNamespace added in v1.0.0

func (b *ApplicationApplyConfiguration) GetNamespace() *string

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (ApplicationApplyConfiguration) IsApplyConfiguration added in v1.0.0

func (b ApplicationApplyConfiguration) IsApplyConfiguration()

func (*ApplicationApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*ApplicationApplyConfiguration) WithAppVersion added in v1.0.0

WithAppVersion sets the AppVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the AppVersion field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithDeletionGracePeriodSeconds

func (b *ApplicationApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *ApplicationApplyConfiguration

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*ApplicationApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*ApplicationApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*ApplicationApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithSpec

WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithStatus

WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.

func (*ApplicationApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type ApplicationStatusApplyConfiguration added in v1.0.0

type ApplicationStatusApplyConfiguration struct {
	Version          *string                          `json:"version,omitempty"`
	Conditions       []v1.ConditionApplyConfiguration `json:"conditions,omitempty"`
	Namespace        *string                          `json:"namespace,omitempty"`
	ExternalIPsCount *int32                           `json:"externalIPsCount,omitempty"`
}

ApplicationStatusApplyConfiguration represents a declarative configuration of the ApplicationStatus type for use with apply.

func ApplicationStatus added in v1.0.0

func ApplicationStatus() *ApplicationStatusApplyConfiguration

ApplicationStatusApplyConfiguration constructs a declarative configuration of the ApplicationStatus type for use with apply.

func (*ApplicationStatusApplyConfiguration) WithConditions added in v1.0.0

WithConditions adds the given value to the Conditions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Conditions field.

func (*ApplicationStatusApplyConfiguration) WithExternalIPsCount added in v1.0.0

WithExternalIPsCount sets the ExternalIPsCount field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ExternalIPsCount field is set to the value of the last call.

func (*ApplicationStatusApplyConfiguration) WithNamespace added in v1.0.0

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*ApplicationStatusApplyConfiguration) WithVersion added in v1.0.0

WithVersion sets the Version field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Version field is set to the value of the last call.

Jump to