tenantmodule

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2026 License: Apache-2.0 Imports: 27 Imported by: 0

Documentation

Index

Constants

const (
	TenantModuleLabelKey   = "internal.cozystack.io/tenantmodule"
	TenantModuleLabelValue = "true"
)

Define constants for label filtering

Variables

This section is empty.

Functions

This section is empty.

Types

type REST

type REST struct {
	// contains filtered or unexported fields
}

REST implements the RESTStorage interface for TenantModule resources

func NewREST

func NewREST(c client.Client, w client.WithWatch) *REST

NewREST creates a new REST storage for TenantModule

func (*REST) ConvertHelmReleaseToTenantModule

func (r *REST) ConvertHelmReleaseToTenantModule(hr *helmv2.HelmRelease) (corev1alpha1.TenantModule, error)

ConvertHelmReleaseToTenantModule converts a HelmRelease to a TenantModule

func (*REST) ConvertToTable

func (r *REST) ConvertToTable(ctx context.Context, object runtime.Object, tableOptions runtime.Object) (*metav1.Table, error)

ConvertToTable implements the TableConvertor interface for displaying resources in a table format

func (*REST) Destroy

func (r *REST) Destroy()

Destroy releases resources associated with REST

func (*REST) Get

func (r *REST) Get(ctx context.Context, name string, options *metav1.GetOptions) (runtime.Object, error)

Get retrieves a TenantModule by converting the corresponding HelmRelease

func (*REST) GetSingularName

func (r *REST) GetSingularName() string

GetSingularName returns the singular name of the resource

func (*REST) GroupVersionKind

func (r *REST) GroupVersionKind(schema.GroupVersion) schema.GroupVersionKind

GroupVersionKind returns the GroupVersionKind for REST

func (*REST) Kind

func (r *REST) Kind() string

Kind returns the resource kind used for API discovery

func (*REST) List

List retrieves a list of TenantModules by converting HelmReleases

func (*REST) NamespaceScoped

func (r *REST) NamespaceScoped() bool

NamespaceScoped indicates whether the resource is namespaced

func (*REST) New

func (r *REST) New() runtime.Object

New creates a new instance of TenantModule

func (*REST) NewList

func (r *REST) NewList() runtime.Object

NewList returns an empty list of TenantModule objects

func (*REST) Watch

Watch sets up a watch on HelmReleases, filters them based on tenant module label, and converts events to TenantModules

Jump to