Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the v1alpha1 API group. +kubebuilder:object:generate=true +groupName=strategy.backups.cozystack.io
SPDX-License-Identifier: Apache-2.0 Package v1alpha1 defines strategy.backups.cozystack.io API types.
Group: strategy.backups.cozystack.io Version: v1alpha1
SPDX-License-Identifier: Apache-2.0 Package v1alpha1 defines strategy.backups.cozystack.io API types.
Group: strategy.backups.cozystack.io Version: v1alpha1
Index ¶
Constants ¶
const (
JobStrategyKind = "Job"
)
const (
VeleroStrategyKind = "Velero"
)
Variables ¶
var ( GroupVersion = schema.GroupVersion{Group: "strategy.backups.cozystack.io", Version: "v1alpha1"} SchemeBuilder = runtime.NewSchemeBuilder(addGroupVersion) AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type Job ¶
type Job struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec JobSpec `json:"spec,omitempty"`
Status JobStatus `json:"status,omitempty"`
}
Job defines a backup strategy using a one-shot Job
func (*Job) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Job.
func (*Job) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Job) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type JobList ¶
type JobList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Job `json:"items"`
}
JobList contains a list of backup Jobs.
func (*JobList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JobList.
func (*JobList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*JobList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type JobSpec ¶
type JobSpec struct {
// Template holds a PodTemplateSpec with the right shape to
// run a single pod to completion and create a tarball with
// a given apps data. Helm-like Go templates are supported.
// The values of the source application are available under
// `.Values`. `.Release.Name` and `.Release.Namespace` are
// also exported.
Template corev1.PodTemplateSpec `json:"template"`
}
JobSpec specifies the desired behavior of a backup job.
func (*JobSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JobSpec.
func (*JobSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type JobStatus ¶
func (*JobStatus) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JobStatus.
func (*JobStatus) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Velero ¶
type Velero struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec VeleroSpec `json:"spec,omitempty"`
Status VeleroStatus `json:"status,omitempty"`
}
Velero defines a backup strategy using Velero as the driver.
func (*Velero) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Velero.
func (*Velero) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Velero) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VeleroList ¶
type VeleroList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Velero `json:"items"`
}
VeleroList contains a list of Velero backup strategies.
func (*VeleroList) DeepCopy ¶
func (in *VeleroList) DeepCopy() *VeleroList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VeleroList.
func (*VeleroList) DeepCopyInto ¶
func (in *VeleroList) DeepCopyInto(out *VeleroList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VeleroList) DeepCopyObject ¶
func (in *VeleroList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VeleroSpec ¶
type VeleroSpec struct {
Template VeleroTemplate `json:"template"`
}
VeleroSpec specifies the desired strategy for backing up with Velero.
func (*VeleroSpec) DeepCopy ¶
func (in *VeleroSpec) DeepCopy() *VeleroSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VeleroSpec.
func (*VeleroSpec) DeepCopyInto ¶
func (in *VeleroSpec) DeepCopyInto(out *VeleroSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VeleroStatus ¶
func (*VeleroStatus) DeepCopy ¶
func (in *VeleroStatus) DeepCopy() *VeleroStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VeleroStatus.
func (*VeleroStatus) DeepCopyInto ¶
func (in *VeleroStatus) DeepCopyInto(out *VeleroStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VeleroTemplate ¶
type VeleroTemplate struct {
Spec velerov1.BackupSpec `json:"spec"`
}
VeleroTemplate describes the data a backup.velero.io should have when templated from a Velero backup strategy.
func (*VeleroTemplate) DeepCopy ¶
func (in *VeleroTemplate) DeepCopy() *VeleroTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VeleroTemplate.
func (*VeleroTemplate) DeepCopyInto ¶
func (in *VeleroTemplate) DeepCopyInto(out *VeleroTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.