Documentation
¶
Index ¶
- type ExecOptions
- type ExecResult
- type KubeOVNPlunger
- func (r *KubeOVNPlunger) ExecPod(ctx context.Context, opts ExecOptions) (*ExecResult, error)
- func (r *KubeOVNPlunger) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
- func (r *KubeOVNPlunger) SetupWithManager(mgr ctrl.Manager, kubeOVNNamespace, appName string) error
- func (r *KubeOVNPlunger) WriteClusterMetrics(db string, snaps []ovnstatus.HealthSnapshot, ...)
- func (r *KubeOVNPlunger) WriteMemberMetrics(db string, snaps []ovnstatus.HealthSnapshot, views []ovnstatus.MemberView, ...)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExecOptions ¶
type ExecResult ¶
type KubeOVNPlunger ¶
type KubeOVNPlunger struct {
client.Client
Scheme *runtime.Scheme
ClientSet kubernetes.Interface
REST *rest.Config
Registry prometheus.Registerer
// contains filtered or unexported fields
}
KubeOVNPlunger watches the ovn-central cluster members
func (*KubeOVNPlunger) ExecPod ¶
func (r *KubeOVNPlunger) ExecPod(ctx context.Context, opts ExecOptions) (*ExecResult, error)
ExecPod runs a command in a pod and returns stdout/stderr/exit code.
func (*KubeOVNPlunger) Reconcile ¶
Reconcile runs the checks on the ovn-central members to see if their views of the cluster are consistent
func (*KubeOVNPlunger) SetupWithManager ¶
func (r *KubeOVNPlunger) SetupWithManager(mgr ctrl.Manager, kubeOVNNamespace, appName string) error
SetupWithManager attaches a generic ticker to trigger a reconcile every <interval> seconds
func (*KubeOVNPlunger) WriteClusterMetrics ¶
func (r *KubeOVNPlunger) WriteClusterMetrics(db string, snaps []ovnstatus.HealthSnapshot, ecv ovnstatus.ExtendedConsensusResult, expectedReplicas int)
func (*KubeOVNPlunger) WriteMemberMetrics ¶
func (r *KubeOVNPlunger) WriteMemberMetrics(db string, snaps []ovnstatus.HealthSnapshot, views []ovnstatus.MemberView, ecv ovnstatus.ExtendedConsensusResult)
Click to show internal directories.
Click to hide internal directories.