Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Install ¶
func Install(ctx context.Context, k8sClient client.Client, writeEmbeddedManifests func(string) error) error
Install installs Flux components using embedded manifests. It extracts the manifests and applies them to the cluster. The namespace is automatically determined from the Namespace object in the manifests.
func WriteEmbeddedManifests ¶
WriteEmbeddedManifests extracts embedded Flux manifests to a temporary directory.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.