Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ValidateApplicationName ¶ added in v1.0.0
ValidateApplicationName validates that an Application name conforms to DNS-1035. This is required because Application names are used to create Kubernetes resources (Services, Namespaces, etc.) that must have DNS-1035 compliant names. Note: length validation is handled separately by validateNameLength in the REST handler, which computes dynamic limits based on Helm release prefix.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.