Documentation
¶
Index ¶
- type ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) GetAPIVersion() *string
- func (b *ApplicationApplyConfiguration) GetKind() *string
- func (b *ApplicationApplyConfiguration) GetName() *string
- func (b *ApplicationApplyConfiguration) GetNamespace() *string
- func (b ApplicationApplyConfiguration) IsApplyConfiguration()
- func (b *ApplicationApplyConfiguration) WithAPIVersion(value string) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithAnnotations(entries map[string]string) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithAppVersion(value string) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithCreationTimestamp(value metav1.Time) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithFinalizers(values ...string) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithGenerateName(value string) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithGeneration(value int64) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithKind(value string) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithLabels(entries map[string]string) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithName(value string) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithNamespace(value string) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithResourceVersion(value string) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithSpec(value apiextensionsv1.JSON) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithStatus(value *ApplicationStatusApplyConfiguration) *ApplicationApplyConfiguration
- func (b *ApplicationApplyConfiguration) WithUID(value types.UID) *ApplicationApplyConfiguration
- type ApplicationStatusApplyConfiguration
- func (b *ApplicationStatusApplyConfiguration) WithConditions(values ...*v1.ConditionApplyConfiguration) *ApplicationStatusApplyConfiguration
- func (b *ApplicationStatusApplyConfiguration) WithExternalIPsCount(value int32) *ApplicationStatusApplyConfiguration
- func (b *ApplicationStatusApplyConfiguration) WithNamespace(value string) *ApplicationStatusApplyConfiguration
- func (b *ApplicationStatusApplyConfiguration) WithVersion(value string) *ApplicationStatusApplyConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApplicationApplyConfiguration ¶
type ApplicationApplyConfiguration struct {
v1.TypeMetaApplyConfiguration `json:",inline"`
*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
AppVersion *string `json:"appVersion,omitempty"`
Spec *apiextensionsv1.JSON `json:"spec,omitempty"`
Status *ApplicationStatusApplyConfiguration `json:"status,omitempty"`
}
ApplicationApplyConfiguration represents a declarative configuration of the Application type for use with apply.
func Application ¶
func Application(name, namespace string) *ApplicationApplyConfiguration
Application constructs a declarative configuration of the Application type for use with apply.
func (*ApplicationApplyConfiguration) GetAPIVersion ¶ added in v1.0.0
func (b *ApplicationApplyConfiguration) GetAPIVersion() *string
GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.
func (*ApplicationApplyConfiguration) GetKind ¶ added in v1.0.0
func (b *ApplicationApplyConfiguration) GetKind() *string
GetKind retrieves the value of the Kind field in the declarative configuration.
func (*ApplicationApplyConfiguration) GetName ¶
func (b *ApplicationApplyConfiguration) GetName() *string
GetName retrieves the value of the Name field in the declarative configuration.
func (*ApplicationApplyConfiguration) GetNamespace ¶ added in v1.0.0
func (b *ApplicationApplyConfiguration) GetNamespace() *string
GetNamespace retrieves the value of the Namespace field in the declarative configuration.
func (ApplicationApplyConfiguration) IsApplyConfiguration ¶ added in v1.0.0
func (b ApplicationApplyConfiguration) IsApplyConfiguration()
func (*ApplicationApplyConfiguration) WithAPIVersion ¶
func (b *ApplicationApplyConfiguration) WithAPIVersion(value string) *ApplicationApplyConfiguration
WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithAnnotations ¶
func (b *ApplicationApplyConfiguration) WithAnnotations(entries map[string]string) *ApplicationApplyConfiguration
WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.
func (*ApplicationApplyConfiguration) WithAppVersion ¶ added in v1.0.0
func (b *ApplicationApplyConfiguration) WithAppVersion(value string) *ApplicationApplyConfiguration
WithAppVersion sets the AppVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the AppVersion field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithCreationTimestamp ¶
func (b *ApplicationApplyConfiguration) WithCreationTimestamp(value metav1.Time) *ApplicationApplyConfiguration
WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithDeletionGracePeriodSeconds ¶
func (b *ApplicationApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *ApplicationApplyConfiguration
WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithDeletionTimestamp ¶
func (b *ApplicationApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *ApplicationApplyConfiguration
WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithFinalizers ¶
func (b *ApplicationApplyConfiguration) WithFinalizers(values ...string) *ApplicationApplyConfiguration
WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.
func (*ApplicationApplyConfiguration) WithGenerateName ¶
func (b *ApplicationApplyConfiguration) WithGenerateName(value string) *ApplicationApplyConfiguration
WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithGeneration ¶
func (b *ApplicationApplyConfiguration) WithGeneration(value int64) *ApplicationApplyConfiguration
WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithKind ¶
func (b *ApplicationApplyConfiguration) WithKind(value string) *ApplicationApplyConfiguration
WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithLabels ¶
func (b *ApplicationApplyConfiguration) WithLabels(entries map[string]string) *ApplicationApplyConfiguration
WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.
func (*ApplicationApplyConfiguration) WithName ¶
func (b *ApplicationApplyConfiguration) WithName(value string) *ApplicationApplyConfiguration
WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithNamespace ¶
func (b *ApplicationApplyConfiguration) WithNamespace(value string) *ApplicationApplyConfiguration
WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithOwnerReferences ¶
func (b *ApplicationApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *ApplicationApplyConfiguration
WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.
func (*ApplicationApplyConfiguration) WithResourceVersion ¶
func (b *ApplicationApplyConfiguration) WithResourceVersion(value string) *ApplicationApplyConfiguration
WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithSpec ¶
func (b *ApplicationApplyConfiguration) WithSpec(value apiextensionsv1.JSON) *ApplicationApplyConfiguration
WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithStatus ¶
func (b *ApplicationApplyConfiguration) WithStatus(value *ApplicationStatusApplyConfiguration) *ApplicationApplyConfiguration
WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.
func (*ApplicationApplyConfiguration) WithUID ¶
func (b *ApplicationApplyConfiguration) WithUID(value types.UID) *ApplicationApplyConfiguration
WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.
type ApplicationStatusApplyConfiguration ¶ added in v1.0.0
type ApplicationStatusApplyConfiguration struct {
Version *string `json:"version,omitempty"`
Conditions []v1.ConditionApplyConfiguration `json:"conditions,omitempty"`
Namespace *string `json:"namespace,omitempty"`
ExternalIPsCount *int32 `json:"externalIPsCount,omitempty"`
}
ApplicationStatusApplyConfiguration represents a declarative configuration of the ApplicationStatus type for use with apply.
func ApplicationStatus ¶ added in v1.0.0
func ApplicationStatus() *ApplicationStatusApplyConfiguration
ApplicationStatusApplyConfiguration constructs a declarative configuration of the ApplicationStatus type for use with apply.
func (*ApplicationStatusApplyConfiguration) WithConditions ¶ added in v1.0.0
func (b *ApplicationStatusApplyConfiguration) WithConditions(values ...*v1.ConditionApplyConfiguration) *ApplicationStatusApplyConfiguration
WithConditions adds the given value to the Conditions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Conditions field.
func (*ApplicationStatusApplyConfiguration) WithExternalIPsCount ¶ added in v1.0.0
func (b *ApplicationStatusApplyConfiguration) WithExternalIPsCount(value int32) *ApplicationStatusApplyConfiguration
WithExternalIPsCount sets the ExternalIPsCount field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ExternalIPsCount field is set to the value of the last call.
func (*ApplicationStatusApplyConfiguration) WithNamespace ¶ added in v1.0.0
func (b *ApplicationStatusApplyConfiguration) WithNamespace(value string) *ApplicationStatusApplyConfiguration
WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.
func (*ApplicationStatusApplyConfiguration) WithVersion ¶ added in v1.0.0
func (b *ApplicationStatusApplyConfiguration) WithVersion(value string) *ApplicationStatusApplyConfiguration
WithVersion sets the Version field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Version field is set to the value of the last call.