Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MaxResourceVersion ¶ added in v0.40.3
MaxResourceVersion returns the maximum resourceVersion from all items in a list. This is useful when the list's ResourceVersion is empty (e.g., from controller-runtime cache).
Types ¶
type REST ¶
type REST struct {
*genericregistry.Store
}
REST is a thin wrapper around genericregistry.Store that also satisfies the GroupVersionKindProvider interface if callers need it later.
Directories
¶
| Path | Synopsis |
|---|---|
|
apps
|
|
|
core
|
|
|
Package sorting provides generic sorting utilities for registry resources.
|
Package sorting provides generic sorting utilities for registry resources. |
Click to show internal directories.
Click to hide internal directories.