Documentation
¶
Index ¶
- Constants
- type REST
- func (r *REST) ConvertHelmReleaseToTenantModule(hr *helmv2.HelmRelease) (corev1alpha1.TenantModule, error)
- func (r *REST) ConvertToTable(ctx context.Context, object runtime.Object, tableOptions runtime.Object) (*metav1.Table, error)
- func (r *REST) Destroy()
- func (r *REST) Get(ctx context.Context, name string, options *metav1.GetOptions) (runtime.Object, error)
- func (r *REST) GetSingularName() string
- func (r *REST) GroupVersionKind(schema.GroupVersion) schema.GroupVersionKind
- func (r *REST) Kind() string
- func (r *REST) List(ctx context.Context, options *metainternalversion.ListOptions) (runtime.Object, error)
- func (r *REST) NamespaceScoped() bool
- func (r *REST) New() runtime.Object
- func (r *REST) NewList() runtime.Object
- func (r *REST) Watch(ctx context.Context, options *metainternalversion.ListOptions) (watch.Interface, error)
Constants ¶
const ( TenantModuleLabelKey = "internal.cozystack.io/tenantmodule" TenantModuleLabelValue = "true" )
Define constants for label filtering
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type REST ¶
type REST struct {
// contains filtered or unexported fields
}
REST implements the RESTStorage interface for TenantModule resources
func (*REST) ConvertHelmReleaseToTenantModule ¶
func (r *REST) ConvertHelmReleaseToTenantModule(hr *helmv2.HelmRelease) (corev1alpha1.TenantModule, error)
ConvertHelmReleaseToTenantModule converts a HelmRelease to a TenantModule
func (*REST) ConvertToTable ¶
func (r *REST) ConvertToTable(ctx context.Context, object runtime.Object, tableOptions runtime.Object) (*metav1.Table, error)
ConvertToTable implements the TableConvertor interface for displaying resources in a table format
func (*REST) Get ¶
func (r *REST) Get(ctx context.Context, name string, options *metav1.GetOptions) (runtime.Object, error)
Get retrieves a TenantModule by converting the corresponding HelmRelease
func (*REST) GetSingularName ¶
GetSingularName returns the singular name of the resource
func (*REST) GroupVersionKind ¶
func (r *REST) GroupVersionKind(schema.GroupVersion) schema.GroupVersionKind
GroupVersionKind returns the GroupVersionKind for REST
func (*REST) List ¶
func (r *REST) List(ctx context.Context, options *metainternalversion.ListOptions) (runtime.Object, error)
List retrieves a list of TenantModules by converting HelmReleases
func (*REST) NamespaceScoped ¶
NamespaceScoped indicates whether the resource is namespaced
func (*REST) Watch ¶
func (r *REST) Watch(ctx context.Context, options *metainternalversion.ListOptions) (watch.Interface, error)
Watch sets up a watch on HelmReleases, filters them based on tenant module label, and converts events to TenantModules